@@ -9,3 +9,11 @@ from partis.utils.sphinx import basic_conf
 globals().update( basic_conf(
   package = 'partis-schema',
   copyright_year = '2022' ) )
+
+intersphinx_mapping['partis.pyproj'] = (
+  "https://nanohmics.bitbucket.io/doc/partis/pyproj",
+  None )
+  
+intersphinx_mapping['partis.utils'] = (
+  "https://nanohmics.bitbucket.io/doc/partis/utils",
+  None )
