@@ -278,7 +278,7 @@ class SchemaProxy( SchemaRef ):
     """
 
     return cls.schema._get_doc(
-      noindex = noindex,
+      noindex = True,
       depth = depth,
       max_depth = max_depth )
 
@@ -748,7 +748,7 @@ class SchemaDeclared( SchemaDep ):
     max_depth = 2 ):
 
     return cls.schema._get_doc(
-      noindex = noindex,
+      noindex = True,
       depth = depth,
       max_depth = max_depth )
 
